@@ -5,15 +5,28 @@ from django.utils.translation import ugettext_lazy as _
 from fluent_contents.extensions import ContentPlugin, plugin_pool
 from fluent_contents.plugins.oembeditem.forms import OEmbedItemForm
 from fluent_contents.plugins.oembeditem.models import OEmbedItem
+import re
+
+re_safe = re.compile(r'[^\w_-]')
 
 
 @plugin_pool.register
 class OEmbedPlugin(ContentPlugin):
     model = OEmbedItem
     category = _('Online content')
-    form = OEmbedItemForm
+    admin_form_template = "admin/fluent_contents/plugins/oembeditem/admin_form.html"
     render_template = "fluent_contents/plugins/oembed/default.html"
 
+    form = OEmbedItemForm
+    fieldsets = (
+        (None, {
+            'fields': (
+                'embed_url',
+                ('embed_max_width', 'embed_max_height'),
+            ),
+        }),
+    )
+
     class Media:
         css = {
             'screen': (
@@ -26,4 +39,8 @@ class OEmbedPlugin(ContentPlugin):
         """
         Allow to style the item based on the type.
         """
-        return ["fluent_contents/plugins/oembed/{type}.html".format(type=instance.type or 'default'), self.render_template]
+        safe_filename = re_safe.sub('', instance.type or 'default')
+        return [
+            "fluent_contents/plugins/oembed/{type}.html".format(type=safe_filename),
+            self.render_template
+        ]
